Module combinig

Module combinig 

Functions

combining
Combines a getter function with a binary operation. Equivalent to Swift’s combining<Root, Value, NewValue>(_ getter: @escaping (Root) -> Value, _ combine: @escaping (Value, Value) -> NewValue) -> (Value, Root) -> NewValue
combining_mut
Combines a getter function with a mutable binary operation. Equivalent to Swift’s combining<Root, Value>(_ getter: @escaping (Root) -> Value, _ combine: @escaping (inout Value, Value) -> Void) -> (inout Value, Root) -> Void
their
Applies a combining function to values extracted from two roots. Equivalent to Swift’s their<Root, Value, NewValue>(_ getter: @escaping (Root) -> Value, _ combining: @escaping (Value, Value) -> NewValue) -> (Root, Root) -> NewValue
their_add
Applies an addition operation to values extracted from two roots.
their_cmp
Applies a comparison function to values extracted from two roots. Equivalent to Swift’s their<Root, Value: Comparable>(_ getter: @escaping (Root) -> Value) -> (Root, Root) -> Bool
their_div
Applies a division operation to values extracted from two roots.
their_eq
Applies an equality comparison to values extracted from two roots. Equivalent to Swift’s their<Root, Value: Equatable>(_ getter: @escaping (Root) -> Value) -> (Root, Root) -> Bool
their_ge
Applies a greater than or equal comparison to values extracted from two roots.
their_gt
Applies a greater than comparison to values extracted from two roots.
their_le
Applies a less than or equal comparison to values extracted from two roots.
their_max
Applies a maximum operation to values extracted from two roots.
their_min
Applies a minimum operation to values extracted from two roots.
their_mul
Applies a multiplication operation to values extracted from two roots.
their_sub
Applies a subtraction operation to values extracted from two roots.