Backward composition of functions.
This module provides functions for composing functions in a backward manner,
where the output of one function becomes the input of the next.
This is commonly seen in operator form as <<< in functional programming languages.
Functions
- compose
- Backward composition of two functions.
- compose3
- Backward composition of three functions.
- compose4
- Backward composition of four functions.
- compose5
- Backward composition of five functions.
- compose6
- Backward composition of six functions.
- compose3_
throwing - Backward composition of three throwing functions with shallow cloning optimization.
- compose4_
throwing - Backward composition of four throwing functions with shallow cloning optimization.
- compose5_
throwing - Backward composition of five throwing functions with shallow cloning optimization.
- compose6_
throwing - Backward composition of six throwing functions with shallow cloning optimization.
- compose_
throwing - Backward composition of two throwing functions with shallow cloning optimization.