compose3_throwing

Function compose3_throwing 

pub fn compose3_throwing<A, B, C, D, E, F, G, H>(
    f: F,
    g: G,
    h: H,
) -> impl Fn(A) -> Result<D, E>
where F: Fn(C) -> Result<D, E> + 'static, G: Fn(B) -> Result<C, E> + 'static, H: Fn(A) -> Result<B, E> + 'static,
Backward composition of three throwing functions with shallow cloning optimization.

Arguments

  • f - A function that takes a value in C and returns a Result<D, E>
  • g - A function that takes a value in B and returns a Result<C, E>
  • h - A function that takes a value in A and returns a Result<B, E>

Returns

A new function that takes a value in A and returns a Result<D, E>