pub fn compose5_throwing<A, B, C, D, E, F, Err, G, H, I, J>(
f: F,
g: G,
h: H,
i: I,
j: J,
) -> impl Fn(A) -> Result<F, Err>Expand description
Backward composition of five throwing functions with shallow cloning optimization.
Arguments
f- A function that takes a value inEand returns aResult<F, Err>g- A function that takes a value inDand returns aResult<E, Err>h- A function that takes a value inCand returns aResult<D, Err>i- A function that takes a value inBand returns aResult<C, Err>j- A function that takes a value inAand returns aResult<B, Err>
Returns
A new function that takes a value in A and returns a Result<F, Err>