Module compose

Module compose 

Backward composition of functions.

This module provides functions for composing functions in a backward manner, where the output of one function becomes the input of the next. This is commonly seen in operator form as <<< in functional programming languages.

Functions

compose
Backward composition of two functions.
compose3
Backward composition of three functions.
compose4
Backward composition of four functions.
compose5
Backward composition of five functions.
compose6
Backward composition of six functions.
compose3_throwing
Backward composition of three throwing functions.
compose4_throwing
Backward composition of four throwing functions.
compose5_throwing
Backward composition of five throwing functions.
compose6_throwing
Backward composition of six throwing functions.
compose_throwing
Backward composition of two throwing functions.