pub fn compose3_throwing<A, B, C, D, E, F, G, H>(
f: F,
g: G,
h: H,
) -> impl Fn(A) -> Result<D, E>Expand description
Backward composition of three throwing functions with shallow cloning optimization.
Arguments
f- A function that takes a value inCand returns aResult<D, E>g- A function that takes a value inBand returns aResult<C, E>h- A function that takes a value inAand returns aResult<B, E>
Returns
A new function that takes a value in A and returns a Result<D, E>